@@ -43,14 +43,13 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.032';
+our $VERSION = '0.033';
 
 use base qw{Astro::Coord::ECI};
 
 use Astro::Coord::ECI::Sun;	# Need for phase of moon calc.
 use Astro::Coord::ECI::Utils qw{:all};
 use Carp;
-use Params::Util 0.25 qw{_CLASSISA};
 use POSIX qw{floor strftime};
 
 
@@ -115,7 +114,7 @@ otherwise.
 sub new {
     my ($class, @args) = @_;
     ref $class and $class = ref $class;
-    if ($Singleton && $weaken && _CLASSISA($class, __PACKAGE__)) {
+    if ( $Singleton && $weaken && _classisa( $class, __PACKAGE__ ) ) {
 	if ($object) {
 	    $object->set (@args) if @args;
 	    return $object;
